from wagtail.blocks import *
from wagtail.images.blocks import ImageChooserBlock
from wagtail.admin.panels import FieldPanel, MultiFieldPanel, FieldRowPanel
from wagtailmodelchooser.blocks import ModelChooserBlock
# from web.models import ExportCountry
from wagtail_color_panel.blocks import NativeColorBlock
from wagtail.documents.blocks import DocumentChooserBlock
from .baseSettings import *


class DocumentBlock(StreamBlock):
    doc_content = StructBlock([
        ("title", CharBlock(required=False)),
        ("doc", DocumentChooserBlock(required=False)),
        ("image", ImageChooserBlock(required=False)),
    ])

    class Meta:
        icon = 'documents'


class CarouselBlock(StructBlock):
    height = IntegerBlock(default=200, min=150, max=400)
    width = IntegerBlock(default=400, min=350, max=600)
    timer = IntegerBlock(default=2000, help_text="Slide time in ms")
    content = StreamBlock(
        [
            ('slide', StructBlock([
                ("image", ImageChooserBlock(required=True)),
                ("title", CharBlock(required=False)),
            ]))
        ]
    )
    # class Meta:
    #     icon = 'user'


class ParagraphBlock(StructBlock):
    text = RichTextBlock()
    alignment = ChoiceBlock(choices=ALIGNMENT_LIST, required=False)
    size = ChoiceBlock(choices=FONT_SIZE_LIST, required=False)
    line_space = ChoiceBlock(choices=LINE_HEIGHT_LIST,
                             required=False, label="Line Spacing")


class HeadingBlock(StructBlock):
    title = CharBlock()
    alignment = ChoiceBlock(choices=ALIGNMENT_LIST, required=False)
    size = ChoiceBlock(choices=FONT_SIZE_LIST, required=False)
    Panels = [
        MultiFieldPanel([
            FieldRowPanel([
                FieldPanel('alignment'),
                FieldPanel('size')

            ])
        ])
    ]


# class ExCountryBlock(StreamBlock):
#     country = ModelChooserBlock('com.ExportCountry')

#     class Meta:
#         icon = 'globe'


class TileViewBlock(StreamBlock):
    tile = StructBlock([
        ("tileBgColor", NativeColorBlock(default="#000000", label="Tile BG Color")),
        ("image", ImageChooserBlock(required=False)),
        ("label", CharBlock(required=False)),
        ("title", CharBlock(required=False)),
    ])


class SocialBlock(StreamBlock):
    social_link = ModelChooserBlock('com.Social')

# class LogoBlock(StreamBlock):
#     logo = ModelChooserBlock('com.CompanyLogo')
    # class Meta:
    #     icon = 'globe'


class ComInfoBlock(StreamBlock):
    info = ModelChooserBlock('com.CompanyInfo')
    # class Meta:
    #     icon = 'globe'


class CategoryBlock(StructBlock):
    line_space = ChoiceBlock(choices=LINE_HEIGHT_LIST, required=False)
    content = StreamBlock(
        [
            ("cat", PageChooserBlock('com.CategoryPage'))
        ], required=False
    )
    # class Meta:
    #     icon = 'globe'


class QuoteBlock(StructBlock):
    quote = BlockQuoteBlock()
    alignment = ChoiceBlock(choices=ALIGNMENT_LIST, required=False)
    size = ChoiceBlock(choices=FONT_SIZE_LIST, required=False)
    line_space = ChoiceBlock(choices=LINE_HEIGHT_LIST, required=False)


class BaseColumnBlock(StructBlock):
    fontType = ChoiceBlock(choices=FONT_TYPE_LIST, required=False)
    content = StreamBlock([
        ("heading",HeadingBlock(required=False)),
        ("quote",QuoteBlock(required=False)),
        ("document",DocumentBlock(required=False)),
        ("paragraph",ParagraphBlock(required=False)),
        ("category",CategoryBlock(required=False)),
        ("tile_View",TileViewBlock(required=False)),
        ("image",ImageChooserBlock(required=False)),
        ("social",SocialBlock(required=False)),
        ("company",ComInfoBlock(required=False)),
        ("show_enq_form",BooleanBlock(required=False, label="Show Enquiry Form"))
    ])


# class BaseColumnBlock(StreamBlock):
#     heading = HeadingBlock(required=False)
#     quote = QuoteBlock(required=False)
#     document = DocumentBlock(required=False)
#     paragraph = ParagraphBlock(required=False)
#     category = CategoryBlock(required=False)
#     tile_View = TileViewBlock(required=False)
#     image = ImageChooserBlock(required=False)
#     social = SocialBlock(required=False)
#     company = ComInfoBlock(required=False)
#     show_enq_form = BooleanBlock(required=False, label="Show Enquiry Form")


class BaseRowBlock(StructBlock):
    bgColor = NativeColorBlock(default="#000000", label="BG Color")
    fgColor = NativeColorBlock(default="#FFFFFF", label="FG Color")
    title = CharBlock(required=False)

    content = StreamBlock(
        [
            ("column", BaseColumnBlock(required=False))
        ],required=False
    )


class ColumnBlock(StructBlock):
    fontType = ChoiceBlock(choices=FONT_TYPE_LIST, required=False)
    content = StreamBlock([
        ("heading",HeadingBlock(required=False)),
        ("quote",QuoteBlock(required=False)),
        ("document",DocumentBlock(required=False)),
        ("paragraph",ParagraphBlock(required=False)),
        ("category",CategoryBlock(required=False)),
        ("tile_View",TileViewBlock(required=False)),
        ("image",ImageChooserBlock(required=False)),
        ("social",SocialBlock(required=False)),
        ("company",ComInfoBlock(required=False)),
        ("sub_row", BaseRowBlock(required=False)),
        ("show_enq_form",BooleanBlock(required=False, label="Show Enquiry Form"))
    ])


# Main Blocks


class RowBlock(StructBlock):
    bgColor = NativeColorBlock(default="#FFFFFF", label="BG Color")
    fgColor = NativeColorBlock(default="#000000", label="FG Color")
    title = CharBlock(required=False)

    content = StreamBlock(
        [
            ("column", ColumnBlock(required=False))
        ], required=False
    )


class SectionBlock(StructBlock):
    bgColor = NativeColorBlock(default="#FFFFFF", label="BG Color")
    fgColor = NativeColorBlock(default="#000000", label="FG Color")
    fontType = ChoiceBlock(choices=FONT_TYPE_LIST, required=False)
    title = CharBlock(required=False)

    content = StreamBlock(
        [
            ("heading", HeadingBlock(required=False)),
            # ("country", ExCountryBlock(required=False)),
            ("document", DocumentBlock(required=False)),
            ("paragraph", ParagraphBlock(required=False)),

            ("category", CategoryBlock(required=False)),
            # ("logos", LogoBlock(required=False)),
            ("tile_View", TileViewBlock(required=False)),
            ("quote", QuoteBlock(required=False)),
        ], required=False
    )
    # class Meta:
    #     icon = 'user'
